(*
 * Inspired by: https://forum.lazarus.freepascal.org/index.php?topic=24506.0
 *
 * Unit to get all Adapternames and their assosiated IP-Addresses
 *
 * Tested unter Linux and Windows
 *)

Unit uip;

{$MODE ObjFPC}{$H+}

Interface

Uses
  Classes, SysUtils;

Type

  TNetworkAdapter = Record
    IpAddress: String;
    AdapterName: String;
  End;

  TNetworkAdapterList = Array Of TNetworkAdapter;

  (*
   * Call this to get all local Adapternames and their IPV-4 addresses
   *)
Function GetLocalIPs(): TNetworkAdapterList;

Implementation

Uses
  process;

Function GetLocalIPs: TNetworkAdapterList;
Var
  sl: TStringList;
  responce, tmp: String;
{$IFDEF Windows}
  j,
{$ENDIF}
  i: Integer;
Begin
  result := Nil;
  sl := TStringList.Create;
{$IFDEF Linux}
  RunCommand('ifconfig', [], responce, [poWaitOnExit]);
{$ENDIF}
{$IFDEF Windows}
  RunCommand('ipconfig', [], responce, [poNoConsole,  poWaitOnExit]);
{$ENDIF}
  sl.Text := responce;
  For i := 1 To sl.Count - 1 Do Begin
{$IFDEF Linux}
    If pos('inet ', sl[i]) <> 0 Then Begin
      setlength(result, high(result) + 2);
      // TODO: Maybe implement a more "Robust" method to get the adapter name ??
      result[high(result)].AdapterName := copy(sl[i - 1], 1, pos(':', sl[i - 1]) - 1);
      tmp := copy(sl[i], pos('inet ', sl[i]) + length('inet '), length(sl[i]));
      result[high(result)].IpAddress := copy(tmp, 1, pos(' ', tmp) - 1);
    End;
{$ENDIF}
{$IFDEF Windows}
    If pos('IPv4-', sl[i]) <> 0 Then Begin
      setlength(result, high(result) + 2);
      tmp := copy(sl[i], pos(':', sl[i]) + 1, length(sl[i]));
      result[high(result)].IpAddress := trim(tmp);
      result[high(result)].AdapterName := 'Could not resolve adapter name';
      For j := i Downto 1 Do Begin
        If trim(sl[j]) = '' Then Begin
          tmp := sl[j - 1];
          tmp := copy(tmp, 1, pos(':', tmp) - 1);
          If tmp <> '' Then Begin
            result[high(result)].AdapterName := tmp;
          End;
          break;
        End;
      End;
    End;
{$ENDIF}
  End;
  sl.free;
End;

End.

